@@ -2,8 +2,11 @@
 
 from .cmap import UnitsColormap
 from .europa import EUROPA
+from .pluto import PLUTO
+
 
 __all__ = [
     'EUROPA',
+    'PLUTO',
     'UnitsColormap',
 ]
